@@ -17,9 +17,11 @@ from .__meta__ import (
 #
 
 from .arrays import (
+    append,
     cat,
     chunk,
     compact,
+    concat,
     difference,
     drop,
     drop_right,
@@ -37,17 +39,24 @@ from .arrays import (
     interleave,
     intersection,
     intersperse,
+    join,
     last,
     last_index_of,
     mapcat,
     object_,
+    pop,
     pull,
     pull_at,
+    push,
     remove,
     rest,
+    reverse,
+    shift,
     slice_,
+    sort,
     sorted_index,
     sorted_last_index,
+    splice,
     split_at,
     tail,
     take,
@@ -57,6 +66,7 @@ from .arrays import (
     union,
     uniq,
     unique,
+    unshift,
     unzip,
     without,
     xor,
@@ -73,7 +83,7 @@ from .chaining import (
     chain,
     tap,
     thru,
-    _Underscore
+    _Dash
 )
 
 
@@ -88,6 +98,7 @@ from .collections import (
     collect,
     contains,
     count_by,
+    deep_pluck,
     detect,
     each,
     each_right,
@@ -106,6 +117,7 @@ from .collections import (
     inject,
     invoke,
     map_,
+    mapiter,
     max_,
     min_,
     partition,
@@ -153,6 +165,33 @@ from .functions import (
 )
 
 
+#
+# Numerical
+#
+
+from .numerical import (
+    add,
+    average,
+    avg,
+    curve,
+    mean,
+    median,
+    moving_average,
+    moving_avg,
+    pow_,
+    power,
+    round_,
+    scale,
+    sigma,
+    slope,
+    std_deviation,
+    sum_,
+    transpose,
+    variance,
+    zscore,
+)
+
+
 #
 # Objects
 #
@@ -162,6 +201,10 @@ from .objects import (
     callables,
     clone,
     clone_deep,
+    deep_get,
+    deep_has,
+    deep_map_values,
+    deep_set,
     defaults,
     extend,
     find_key,
@@ -260,6 +303,7 @@ from .strings import (
     trim_right,
     trunc,
     unescape,
+    url,
     words,
 )
 
@@ -271,6 +315,8 @@ from .utilities import (
     attempt,
     callback,
     constant,
+    deep_property,
+    deep_prop,
     iteratee,
     identity,
     matches,
@@ -300,4 +346,4 @@ from .exceptions import (
 # "_" Instance
 #
 
-_ = _Underscore()
+_ = _Dash()
