@@ -1,22 +1,14 @@
 """Define project metadata
 """
 
-__all__ = [
-    '__title__',
-    '__summary__',
-    '__url__',
-    '__version__',
-    '__author__',
-    '__email__',
-    '__license__',
-]
-
 __title__ = 'pydash'
 __summary__ = ('A utility library for doing "stuff" in a functional way. '
                'Based on the Lo-Dash Javascript library.')
 __url__ = 'https://github.com/dgilland/pydash'
 
-__version__ = '2.0.0'
+__version__ = '2.3.0'
+
+__install_requires__ = []
 
 __author__ = 'Derrick Gilland'
 __email__ = 'dgilland@gmail.com'
