@@ -10,12 +10,15 @@ from math import ceil
 
 import pydash as pyd
 from .helpers import itercallback
+from ._compat import cmp_to_key
 
 
 __all__ = [
+    'append',
     'cat',
     'chunk',
     'compact',
+    'concat',
     'difference',
     'drop',
     'drop_right',
@@ -33,17 +36,23 @@ __all__ = [
     'interleave',
     'intersection',
     'intersperse',
+    'join',
     'last',
     'last_index_of',
     'mapcat',
     'object_',
     'pull',
     'pull_at',
+    'push',
     'remove',
     'rest',
+    'reverse',
+    'shift',
     'slice_',
+    'sort',
     'sorted_index',
     'sorted_last_index',
+    'splice',
     'split_at',
     'tail',
     'take',
@@ -56,6 +65,7 @@ __all__ = [
     'without',
     'xor',
     'zip_',
+    'unshift',
     'unzip',
     'zip_object',
 ]
@@ -75,6 +85,9 @@ def cat(*arrays):
     return flatten(arrays)
 
 
+concat = cat
+
+
 def chunk(array, size=1):
     """Creates a list of elements split into groups the length of `size`. If
     `array` can't be split evenly, the final chunk will be the remaining
@@ -391,6 +404,21 @@ def intersperse(array, separator):
     return list(iterintersperse(array, separator))
 
 
+def join(array, separator):
+    """Return the elements of `array` as a string joined with `separator`.
+
+    Args:
+        array (list): List to join.
+        separator (str): String to join with.
+
+    Returns:
+        str: Joined string.
+
+    ..versionadded:: 2.2.0
+    """
+    return separator.join(pyd.map_(array, pyd.to_string))
+
+
 def last(array):
     """Return the last element of `array`.
 
@@ -446,6 +474,24 @@ def mapcat(array, callback=None):
     return cat(*pyd.map_(array, callback))
 
 
+def pop(array, index=-1):
+    """Remove element of array at `index` and return element.
+
+    Args:
+        array (list): List to pop from.
+        index (int, optional): Index to remove element from. Default is ``-1``.
+
+    Returns:
+        mixed: Value at `index`.
+
+    Warning:
+        `array` is modified in place.
+
+    .. versionadded:: 2.2.0
+    """
+    return array.pop(index)
+
+
 def pull(array, *values):
     """Removes all provided values from the given array.
 
@@ -492,6 +538,28 @@ def pull_at(array, *indexes):
     return array
 
 
+def push(array, *items):
+    """Push items onto the end of `array` and return modified `array`.
+
+    Args:
+        array (list): List to push to.
+        *items (mixed): Items to append.
+
+    Returns:
+        list: Modified `array`.
+
+    Warning:
+        `array` is modified in place.
+
+    .. versionadded:: 2.2.0
+    """
+    pyd.each(items, lambda item: array.append(item))
+    return array
+
+
+append = push
+
+
 def remove(array, callback=None):
     """Removes all elements from a list that the callback returns truthy for
     and returns an array of removed elements.
@@ -537,6 +605,39 @@ def rest(array):
 tail = rest
 
 
+def reverse(array):
+    """Return `array` in reverse order.
+
+    Args:
+        array (list|string): Object to process.
+
+    Returns:
+        list|string: Reverse of object.
+
+    .. versionadded:: 2.2.0
+    """
+    # NOTE: Using this method to reverse object since it works for both lists
+    # and strings.
+    return array[::-1]
+
+
+def shift(array):
+    """Remove the first element of `array` and return it.
+
+    Args:
+        array (list): List to shift.
+
+    Returns:
+        mixed: First element of `array`.
+
+    Warning:
+        `array` is modified in place.
+
+    .. versionadded:: 2.2.0
+    """
+    return pop(array, 0)
+
+
 def slice_(array, start=0, end=None):
     """Slices `array` from the `start` index up to, but not including, the
     `end` index.
@@ -558,6 +659,48 @@ def slice_(array, start=0, end=None):
     return array[start:end]
 
 
+def sort(array, comparison=None, key=None, reverse=False):
+    """Sort `array` using optional `comparison`, `key`, and `reverse` options
+    and return sorted `array`.
+
+    Note:
+        Python 3 removed the option to pass a custom comparison function and
+        instead only allows a key function. Therefore, if a comparison
+        function is passed in, it will be converted to a key function
+        automatically using ``functools.cmp_to_key``.
+
+    Args:
+        array (list): List to sort.
+        comparison (callable, optional): A custom comparison function used to
+            sort the list. Function should accept two arguments and return a
+            negative, zero, or position number depending on whether the first
+            argument is considered smaller than, equal to, or larger than the
+            second argument. Default is ``None``. This argument is mutually
+            exclusive with `key`.
+        key (callback, optional): A function of one argument used to extract a
+            a comparison key from each list element. Default is ``None``. This
+            argument is mutually exclusive with `comparison`.
+        reverse: Whether to reverse the sort. Default is ``False``.
+
+    Returns:
+        list: Sorted list.
+
+    Warning:
+        `array` is modified in place.
+
+    .. versionadded:: 2.2.0
+    """
+    if comparison and key:
+        raise Exception(
+            'The "comparison" and "key" arguments are mutually exclusive')
+
+    if comparison:
+        key = cmp_to_key(comparison)
+
+    array.sort(key=key, reverse=reverse)
+    return array
+
+
 def sorted_index(array, value, callback=None):
     """Determine the smallest index at which the value should be inserted into
     array in order to maintain the sort order of the sorted array. If callback
@@ -613,6 +756,39 @@ def sorted_last_index(array, value, callback=None):
     return bisect_right(array, value)
 
 
+def splice(array, index, how_many=None, *items):
+    """Modify the contents of `array` by inserting elements starting at `index`
+    and removing `how_many` number of elements after `index`.
+
+    Args:
+        array (list): List to splice.
+        index (int): Index to splice at.
+        how_many (int, optional): Number of items to remove starting at
+            `index`. If ``None`` then all items after `index` are removed.
+            Default is ``None``.
+        *items (mixed): Elements to insert starting at `index`. Each item is
+            inserted in the order given.
+
+    Returns:
+        list: The removed elements of `array`.
+
+    Warning:
+        `array` is modified in place.
+
+    .. versionadded:: 2.2.0
+    """
+    if how_many is None:
+        how_many = len(array) - index
+
+    removed = array[index:index + how_many]
+    del array[index:index + how_many]
+
+    for item in reverse(items):
+        array.insert(index, item)
+
+    return removed
+
+
 def split_at(array, index):
     """Returns a list of two lists composed of the split of `array` at `index`.
 
@@ -807,6 +983,28 @@ def zip_(*arrays):
     return [list(item) for item in zip(*arrays)]
 
 
+def unshift(array, *items):
+    """Insert the given elements at the beginning of `array` and return the
+    modified list.
+
+    Args:
+        array (list): List to modify.
+        *items (mixed): Items to insert.
+
+    Returns:
+        list: Modified list.
+
+    Warning:
+        `array` is modified in place.
+
+    .. versionadded:: 2.2.0
+    """
+    for item in reverse(items):
+        array.insert(0, item)
+
+    return array
+
+
 def unzip(array):
     """The inverse of :func:`zip_`, this method splits groups of
     elements into lists composed of elements from each group at their
