@@ -25,6 +25,10 @@ __all__ = [
     'callables',
     'clone',
     'clone_deep',
+    'deep_get',
+    'deep_has',
+    'deep_set',
+    'deep_map_values',
     'defaults',
     'extend',
     'find_key',
@@ -170,6 +174,100 @@ def clone_deep(value, callback=None):
     return clone(value, is_deep=True, callback=callback)
 
 
+def deep_get(obj, path):
+    """Get the value at any depth of a nested object based on the path
+    described by `path`. If path doesn't exist, ``None`` is returned.
+
+    Args:
+        obj (list|dict): Object to process.
+        keys (str|list): List or ``.`` delimited string of keys describing
+            path.
+
+    Returns:
+        mixed: Value of `obj` at path.
+
+    .. versionadded:: 2.2.0
+    """
+    return get_path(obj, path)
+
+
+def deep_has(obj, path):
+    """Checks if `path` exists as a key of `obj`.
+
+    Args:
+        obj (mixed): Object to test.
+        path (mixed): Path to test for. Can be a list of nested keys or a ``.``
+            delimited string of path describing the path.
+
+    Returns:
+        bool: Whether `obj` has `path`.
+
+    See Also:
+        - :func:`deep_has` (main definition)
+        - :func:`has_path` (alias)
+
+    .. versionchanged: 2.2.0
+        Made :func:`has_path` an alias.
+    """
+    try:
+        get_path(obj, path, default=NoValue)
+        exists = True
+    except (KeyError, IndexError, TypeError):
+        exists = False
+
+    return exists
+
+
+has_path = deep_has
+
+
+def deep_map_values(obj, callback=None, property_path=NoValue):
+    """Map all non-object values in `obj` with return values from `callback`.
+    The callback is invoked with two arguments: ``(obj_value, property_path)``
+    where ``property_path`` contains the list of path keys corresponding to the
+    path of ``obj_value``.
+
+    Args:
+        obj (list|dict): Object to map.
+        callback (callable): Callback applied to each value.
+
+    Returns:
+        mixed: The modified object.
+
+    Warning:
+        `obj` is modified in place.
+
+    .. versionadded: 2.2.0
+    """
+    properties = path_keys(property_path)
+
+    if pyd.is_object(obj):
+        deep_callback = (
+            lambda value, key: deep_map_values(value,
+                                               callback,
+                                               pyd.flatten([properties, key])))
+        return pyd.extend(obj, map_values(obj, deep_callback))
+    else:
+        return callback(obj, properties)
+
+
+def deep_set(obj, path, value):
+    """Sets the value of an object described by `path`. If any part of the
+    object path doesn't exist, it will be created.
+
+    Args:
+        obj (list|dict): Object to modify.
+        path (str | list): Target path to set value to.
+        value (mixed): Value to set.
+
+    Returns:
+        mixed: Modified `obj`.
+
+    .. versionadded:: 2.2.0
+    """
+    return set_path(obj, value, path_keys(path))
+
+
 def defaults(obj, *sources):
     """Assigns own enumerable properties of source object(s) to the destination
     object for all destination properties that resolve to undefined.
@@ -271,24 +369,24 @@ def for_in_right(obj, callback=None):
 for_own_right = for_in_right
 
 
-def get_path(obj, keys, default=None):
+def get_path(obj, path, default=None):
     """Get the value at any depth of a nested object based on the path
-    described by `keys`. If path doesn't exist, ``None`` is returned.
+    described by `path`. If path doesn't exist, ``None`` is returned.
 
     Args:
         obj (list|dict): Object to process.
-        keys (str|list): List or ``.`` delimited string of keys describing
-            path. When `keys` is a string, use ``[index]`` as the path key to
-            access list indexes. For example, ``'one.[2].three.[4]'``.
+        path (str|list): List or ``.`` delimited string of path describing
+            path.
 
     Returns:
         mixed: Value of `obj` at path.
 
     .. versionadded:: 2.0.0
-    """
-    # pylint: disable=redefined-outer-name
 
-    for key in path_keys(keys):
+    .. versionchanged:: 2.2.0
+        Support escaping "." delimiter in single string path key.
+    """
+    for key in path_keys(path):
         obj = get_item(obj, key, default=default)
         if obj is None:
             break
@@ -308,31 +406,7 @@ def has(obj, key):
 
     .. versionadded:: 1.0.0
     """
-    return has_path(obj, [key])
-
-
-def has_path(obj, keys):
-    """Returns whether obj has path described by `keys`.
-
-    Args:
-        obj (list|dict): Object to process.
-        keys (str|list): List or ``.`` delimited string of keys describing
-            path. When `keys` is a string, use ``[index]`` as the path key to
-            access list indexes. For example, ``'one.[2].three.[4]'``.
-
-    Returns:
-        bool: Whether `obj` has path.
-
-    .. versionadded:: 2.0.0
-    """
-    # pylint: disable=redefined-outer-name
-    try:
-        get_path(obj, keys, default=NoValue)
-        exists = True
-    except (KeyError, IndexError, TypeError):
-        exists = False
-
-    return exists
+    return deep_has(obj, [key])
 
 
 def invert(obj, multivalue=False):
@@ -725,13 +799,33 @@ values_in = values
 
 
 def path_keys(keys):
-    """Convert keys used to access an object's path into the standard form, a
+    """Convert keys used to access an object's path into the standard form: a
     list of keys.
     """
     # pylint: disable=redefined-outer-name
     if pyd.is_string(keys):
+        # This matches "." as delimiter unless it is escaped by "//".
+        re_dot_delim = re.compile(r'(?<!\\)(?:\\\\)*\.')
+
+        # Since we can't tell whether a bare number is supposed to be dict key
+        # or a list index, we support a special syntax where any string-integer
+        # surrounded by brackets is treated as a list index and converted to an
+        # integer.
         re_list_index = re.compile(r'\[[\d\]]')
-        keys = [int(key[1:-1]) if re_list_index.match(key) else key
-                for key in keys.split('.')]
+
+        keys = [int(key[1:-1]) if re_list_index.match(key)
+                else unescape_path_key(key)
+                for key in re_dot_delim.split(keys)]
+    elif pyd.is_number(keys):
+        keys = [keys]
+    elif keys is NoValue:
+        keys = []
 
     return keys
+
+
+def unescape_path_key(key):
+    """Unescape path key."""
+    key = pyd.js_replace(r'/\\\\/g', key, r'\\')
+    key = pyd.js_replace(r'/\\\./g', key, '.')
+    return key
